@@ -15,19 +15,19 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#define ARROW_VERSION_MAJOR 9
-#define ARROW_VERSION_MINOR 0
+#define ARROW_VERSION_MAJOR 16
+#define ARROW_VERSION_MINOR 1
 #define ARROW_VERSION_PATCH 0
 #define ARROW_VERSION ((ARROW_VERSION_MAJOR * 1000) + ARROW_VERSION_MINOR) * 1000 + ARROW_VERSION_PATCH
 
-#define ARROW_VERSION_STRING "9.0.0"
+#define ARROW_VERSION_STRING "16.1.0"
 
-#define ARROW_SO_VERSION "900"
-#define ARROW_FULL_SO_VERSION "900.0.0"
+#define ARROW_SO_VERSION "1601"
+#define ARROW_FULL_SO_VERSION "1601.0.0"
 
 #define ARROW_CXX_COMPILER_ID "Clang"
-#define ARROW_CXX_COMPILER_VERSION "14.0.6"
-#define ARROW_CXX_COMPILER_FLAGS "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -Wp,-D_GLIBCXX_ASSERTIONS -flto=auto -Qunused-arguments -fcolor-diagnostics -O3 -DNDEBUG"
+#define ARROW_CXX_COMPILER_VERSION "17.0.6"
+#define ARROW_CXX_COMPILER_FLAGS "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -Wp,-D_GLIBCXX_ASSERTIONS -flto=auto -Qunused-arguments -fcolor-diagnostics"
 
 #define ARROW_BUILD_TYPE "RELEASE"
 
@@ -42,15 +42,32 @@
 #define ARROW_DATASET
 #define ARROW_FILESYSTEM
 #define ARROW_FLIGHT
+#define ARROW_FLIGHT_SQL
 #define ARROW_IPC
 #define ARROW_JEMALLOC
 #define ARROW_JEMALLOC_VENDORED
 #define ARROW_JSON
+/* #undef ARROW_MIMALLOC */
+#define ARROW_ORC
+#define ARROW_PARQUET
+#define ARROW_SUBSTRAIT
 
+/* #undef ARROW_AZURE */
+#define ARROW_ENABLE_THREADING
 /* #undef ARROW_GCS */
+#define ARROW_HDFS
 /* #undef ARROW_S3 */
+#define ARROW_USE_GLOG
 #define ARROW_USE_NATIVE_INT128
+#define ARROW_WITH_BROTLI
+#define ARROW_WITH_BZ2
+#define ARROW_WITH_LZ4
+/* #undef ARROW_WITH_MUSL */
 /* #undef ARROW_WITH_OPENTELEMETRY */
+#define ARROW_WITH_RE2
+#define ARROW_WITH_SNAPPY
 /* #undef ARROW_WITH_UCX */
-
-#define GRPCPP_PP_INCLUDE
+#define ARROW_WITH_UTF8PROC
+#define ARROW_WITH_ZLIB
+#define ARROW_WITH_ZSTD
+#define PARQUET_REQUIRE_ENCRYPTION
